import { getRndInteger } from '../../utils/utils.js'
import { getOssPermission } from '../../api/request.js'
import { saveFileInfo, getMeetingRoomAffairs, createMeetingTask, deleteMeetingTask, updateMeetingTask, uploadPermissions } from '../../api/request';
import pageStore from './store'

/* 
fileTypeRepleaceList 请求头替换列表
用途: 根据文件类型替换成相应在请求头 用于oss上传
 */
const requestHeaderRepleacelist = new Map([
    ['bmp', 'image/bmp'],
    ['gif', 'image/gif'],
    ['html', 'text/html'],
    ['txt', 'text/plain'],
    ['vsd', 'application/vnd.visio'],
    ['bmp', 'image/bmp'],
    ['pptx', 'application/vnd.ms-powerpoint'],
    ['ppt', 'application/vnd.ms-powerpoint'],
    ['docx', 'application/msword'],
    ['doc', 'aapplication/msword'],
    ['xml', 'text/xml']
])
// 获取oss上传图片 选择图片 上传图片到oss
function getOssImg() {
    return new Promise((resolve, rejects) => {
        dd.chooseImage({
            count: 1,
            success: (res) => {
                resolve(res)
            },
        });
    })
}
// 获取的图片上传到oss
function sendOss(permisson, imgInfo, key, fileName) {
    return new Promise(resolve => {
        dd.uploadFile({
            headers: {
                "Content-Type": 'image/jpg'
            },
            url: permisson.data.data.host,
            fileType: 'image',
            fileName: 'file',
            filePath: imgInfo.filePaths[0],
            formData: {
                key: key,
                policy: permisson.data.data.policy,
                OSSAccessKeyId: permisson.data.data.accessId,
                success_action_status: 200,
                signature: permisson.data.data.signature
            },
            success: (res) => {
                console.log(JSON.stringify(res))
                resolve([{
                    fileId: key,
                    fileName: fileName,
                    fileType: imgInfo.files[0].fileType,
                    fileSize: imgInfo.files[0].size
                }])
            }
        })
    })
}
// 上传oss文件 保存到我方服务器
function saveOssFileInfo(permisson, imgInfo, key, fileName) {
    const data = {
        resourceType: 'accessory',
        creatorId: getApp().globalData.userid,
        category: '2',
        scheduleId: pageStore.data.scheduleId,
        groupId: pageStore.data.groupId,
        creatorInfo: getApp().globalData.userInfo,
        description: '',
        logType: 'schedule_accessory_add',
        fileInfos: JSON.stringify([{
            fileId: key,
            fileName: fileName,
            fileType: imgInfo.files[0].fileType,
            fileSize: imgInfo.files[0].size
        }]),
        thirdStoreTenant: 'oss'
    }
    saveFileInfo(data).then(result => {
        dd.alert({
            title: '上传成功',
            content: JSON.stringify(result)
        })
    })
}
// 根据上传文件类型改变请求头格式 *******不改变预览会下载文件********
function setRequestHeader(fileType) {
    if (!!requestHeaderRepleacelist.get(fileType)) {
        return requestHeaderRepleacelist.get(fileType)
    } else {
        return "image/jpg";
    }
}
// 对外暴露方法 上传至oss
export async function uploadOss() {
    const timestamp = new Date().getTime()
    const random = getRndInteger(1000, 10000)
    const permisson = await getOssPermission()
    const imgInfo = await getOssImg()
    const key = await new Promise((resolve) => { resolve(permisson.data.data.dir + timestamp + random + '.' + imgInfo.files[0].fileType) })
    const fileName = await new Promise((resolve) => { resolve(timestamp + random + '.' + imgInfo.files[0].fileType) })
    return await sendOss(permisson, imgInfo, key, fileName)
}
